@@ -1,5 +1,11 @@
 # config:utf8
 import os
+import pprint
+import logging
+_logger = logging.getLogger(__file__)
+
+class PyShotgunError(Exception):
+    pass
 
 
 class SGSchema(object):
@@ -71,8 +77,8 @@ class SG_Base(object):
         if self.api is None:
             self.api = SGSchema.api
         if self.api is None:
-            raise RuntimeError('use set_api first')
-        self.logger = logger
+            raise PyShotgunError('use set_api first')
+        self.logger = logger if logger else _logger
         self.return_list = SGSchema.DEFAULT_RETURN[self.type_]
         self._attrs = dict()
         self._sg_attrs = dict()
@@ -85,7 +91,17 @@ class SG_Base(object):
             self.type_,
             [['id', 'is', self.id_]],
             self.return_list)
-        self._sg_attrs.update(sg_data)
+        if not sg_data:
+            raise PyShotgunError(f'Can Not Find {self.type_}({self.id_})')
+        try:
+            self._sg_attrs.update(sg_data)
+        except TypeError as e:
+            msg = {'error_msg':str(e),
+                   'sg_data':sg_data,
+                   'self._sg_attrs': self._sg_attrs}
+            msg_str = pprint.pformat(msg, indent=4)
+            self.logger.error(msg_str)
+            raise PyShotgunError(msg) from e
 
     def _schema(self):
         if not self._schema_dict:
@@ -99,7 +115,7 @@ class SG_Base(object):
             self._find_attrs()
             return self._attr_get_(attr_)
         else:
-            raise AttributeError(
+            raise PyShotgunError(
                 'shotgun entity type:%s, has no attribute:%s\nvalid value are %s' % (self.type_, attr_, self._schema_dict.keys()))
 
     def _attr_get_(self, attr_):
@@ -138,7 +154,7 @@ class SG_Base(object):
         try:
             return self.__getattr__(name_code)
         except AttributeError as e:
-            raise RuntimeError(
+            raise PyShotgunError(
                 f'No support "name_" method for {self.type} type') from e
 
     def __str__(self):
